summaryrefslogtreecommitdiffstats
path: root/kmail/identitydrag.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/identitydrag.h')
-rw-r--r--kmail/identitydrag.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmail/identitydrag.h b/kmail/identitydrag.h
index b9b8b831..82d6d026 100644
--- a/kmail/identitydrag.h
+++ b/kmail/identitydrag.h
@@ -34,27 +34,27 @@
#include <libkpimidentities/identity.h>
-#include <qdragobject.h> // is a qobject and a qmimesource
+#include <tqdragobject.h> // is a qobject and a qmimesource
namespace KMail {
/** @short A QDragObject for KPIM::Identity
@author Marc Mutz <mutz@kde.org>
**/
- class IdentityDrag : public QDragObject {
+ class IdentityDrag : public TQDragObject {
Q_OBJECT
public:
IdentityDrag( const KPIM::Identity & ident,
- QWidget * dragSource=0, const char * name=0 );
+ TQWidget * dragSource=0, const char * name=0 );
public:
virtual ~IdentityDrag() {}
const char * format( int i ) const; // reimp. QMimeSource
- QByteArray encodedData( const char * mimetype ) const; // dto.
+ TQByteArray encodedData( const char * mimetype ) const; // dto.
- static bool canDecode( const QMimeSource * e );
- static bool decode( const QMimeSource * e, KPIM::Identity & ident );
+ static bool canDecode( const TQMimeSource * e );
+ static bool decode( const TQMimeSource * e, KPIM::Identity & ident );
protected:
KPIM::Identity mIdent;
@@ -34,27 +34,27 @@
namespace KMail {
- /** @short A QDragObject for KPIM::Identity
+ /** @short A TQDragObject for KPIM::Identity
**/